import request from '@/plugins/request/system';


/**
 * 获取广告分类
 * @param data
 * @constructor
 */
export function  SystemAdverPage(data = {}) {
  return request({
    url: '/systemv1/adver/page',
    method: 'post',
    data : data
  });
}

/**
 * 获取广告分类tree
 * @param data
 * @constructor
 */
export function  SystemAdverPageTree(data = {}) {
  return request({
    url: '/systemv1/adver/page_tree',
    method: 'post',
    data : data
  });
}
/**
 * 删除广告分类
 * @param data
 * @constructor
 */
export function  SystemAdverPageDel(data = {}) {
  return request({
    url: '/systemv1/adver/page_del',
    method: 'post',
    data : data
  });
}
/**
 * 广告分类详情
 * @param data
 * @constructor
 */
export function  SystemAdverPageInfo(data = {}) {
  return request({
    url: '/systemv1/adver/page_info',
    method: 'post',
    data : data
  });
}

/**
 * 修改广告分类
 * @param data
 * @constructor
 */
export function SystemAdverPageUpdate(data = {}) {
  return request({
    url: '/systemv1/adver/page_save',
    method: 'post',
    data : data
  });
}




/**
 *广告列表
 * @param data
 * @constructor
 */
export function  SystemAdver(data = {}) {
  return request({
    url: '/systemv1/adver/list',
    method: 'post',
    data : data
  });
}

/**
 * 删除广告
 * @param data
 * @constructor
 */
export function  SystemAdverDel(data = {}) {
  return request({
    url: '/systemv1/adver/del',
    method: 'post',
    data : data
  });
}
/**
 * 广告详情
 * @param data
 * @constructor
 */
export function  SystemAdverInfo(data = {}) {
  return request({
    url: '/systemv1/adver/info',
    method: 'post',
    data : data
  });
}

/**
 * 修改广告
 * @param data
 * @constructor
 */
export function  SystemAdverUpdate(data = {}) {
  return request({
    url: '/systemv1/adver/save',
    method: 'post',
    data : data
  });
}

/**
 * 资源图片列表
 * @param data
 * @constructor
 */
export function  SystemUpsourceList(data = {}) {
  return request({
    url: '/systemv1/adver/upsourceList',
    method: 'post',
    data : data
  });
}
/**
 * 编辑添加资源图片
 * @param data
 * @constructor
 */
export function  SystemUpsourceDel(data = {}) {
  return request({
    url: '/systemv1/adver/upsourceDel',
    method: 'post',
    data : data
  });
}
/**
 * 删除资源图片
 * @param data
 * @constructor
 */
export function  SystemUpsourceSave(data = {}) {
  return request({
    url: '/systemv1/adver/upsourceSave',
    method: 'post',
    data : data
  });
}
